@@ -4,8 +4,8 @@
 
 ;; Author: Nicolas Petton <petton.nicolas@gmail.com>
 ;;         Damien Cassou <damien@cassou.me>
-;; Package-Version: 20260109.1144
-;; Package-Revision: de4adfaeba5e
+;; Package-Version: 20260214.2130
+;; Package-Revision: 143456809fd2
 ;; URL: https://github.com/NicolasPetton/pass
 ;; Package-Requires: ((emacs "25.1") (password-store "1.7.4") (password-store-otp "0.1.5") (f "0.17"))
 ;; Created: 09 Jun 2015
@@ -681,7 +681,8 @@ This function only works when `pass-view-mode' is enabled."
   "Display OTP TOKEN and REMAINING-SECS in Header Line."
   (let ((otp-data (concat (propertize " " 'display '((space :align-to 0)))
                           (propertize "OTP: " 'face 'pass-mode-header-face)
-                          token " - " remaining-secs "s remaining"))
+                          (string-trim token)
+                          " - " remaining-secs "s remaining"))
         (key-binding (concat (propertize (substitute-command-keys
                                           (format "<\\[%s]>" "pass-view-copy-token"))
                                          'face 'pass-mode-keybinding-face)
